Coverage for /Users/marco/Code/django-rosetta/rosetta/__init__: 100.00%

# Coverage for /Users/marco/Code/django-rosetta/rosetta/__init__ : 100.00%

## 3 statements 3 run 0 missing 0 excluded 0 partial

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 | VERSION = (0, 7, 1) def get_version(svn=False, limit=3): "Returns the version as a human-format string." return '.'.join([str(i) for i in VERSION[:limit]])